@@ -1,5 +1,7 @@
 var group__spa__control =
 [
+    [ "control.h", "spa_2include_2spa_2control_2control_8h.html", null ],
+    [ "type-info.h", "control_2type-info_8h.html", null ],
     [ "SPA_TYPE_INFO_Control", "group__spa__control.html#ga9b962fde9cc692dbe986897dde0c0d12", null ],
     [ "SPA_TYPE_INFO_CONTROL_BASE", "group__spa__control.html#gadf0c4f48af09389e78636d98a64372d3", null ],
     [ "spa_control_type", "group__spa__control.html#ga9780c9a5192589544170788a97f20b82", [
