@@ -1,5 +1,6 @@
 var NAVTREEINDEX17 =
 {
+"page_midi.html#autotoc_md25":[5,7,0,4],
 "page_midi.html#autotoc_md26":[5,7,1],
 "page_midi.html#autotoc_md27":[5,7,1,0],
 "page_midi.html#autotoc_md28":[5,7,1,1],
@@ -9,31 +10,32 @@ var NAVTREEINDEX17 =
 "page_midi.html#autotoc_md32":[5,7,2,1],
 "page_module_access.html":[6,0],
 "page_module_adapter.html":[6,1],
-"page_module_client_device.html":[6,2],
-"page_module_client_node.html":[6,3],
-"page_module_echo_cancel.html":[6,4],
-"page_module_example_sink.html":[6,5],
-"page_module_example_source.html":[6,6],
-"page_module_fallback_sink.html":[6,7],
-"page_module_filter_chain.html":[6,8],
-"page_module_link_factory.html":[6,9],
-"page_module_loopback.html":[6,10],
-"page_module_metadata.html":[6,11],
-"page_module_pipe_tunnel.html":[6,12],
-"page_module_portal.html":[6,13],
-"page_module_profiler.html":[6,14],
-"page_module_protocol_native.html":[6,15],
-"page_module_protocol_pulse.html":[6,16],
-"page_module_protocol_simple.html":[6,17],
-"page_module_pulse_tunnel.html":[6,18],
-"page_module_raop_discover.html":[6,20],
-"page_module_raop_sink.html":[6,19],
-"page_module_roc_sink.html":[6,21],
-"page_module_roc_source.html":[6,22],
-"page_module_rt.html":[6,23],
-"page_module_session_manager.html":[6,24],
-"page_module_x11_bell.html":[6,25],
-"page_module_zeroconf_discover.html":[6,26],
+"page_module_avb.html":[6,2],
+"page_module_client_device.html":[6,3],
+"page_module_client_node.html":[6,4],
+"page_module_echo_cancel.html":[6,5],
+"page_module_example_sink.html":[6,6],
+"page_module_example_source.html":[6,7],
+"page_module_fallback_sink.html":[6,8],
+"page_module_filter_chain.html":[6,9],
+"page_module_link_factory.html":[6,10],
+"page_module_loopback.html":[6,11],
+"page_module_metadata.html":[6,12],
+"page_module_pipe_tunnel.html":[6,13],
+"page_module_portal.html":[6,14],
+"page_module_profiler.html":[6,15],
+"page_module_protocol_native.html":[6,16],
+"page_module_protocol_pulse.html":[6,17],
+"page_module_protocol_simple.html":[6,18],
+"page_module_pulse_tunnel.html":[6,19],
+"page_module_raop_discover.html":[6,21],
+"page_module_raop_sink.html":[6,20],
+"page_module_roc_sink.html":[6,22],
+"page_module_roc_source.html":[6,23],
+"page_module_rt.html":[6,24],
+"page_module_session_manager.html":[6,25],
+"page_module_x11_bell.html":[6,26],
+"page_module_zeroconf_discover.html":[6,27],
 "page_objects_design.html":[5,8],
 "page_objects_design.html#autotoc_md68":[5,8,0],
 "page_objects_design.html#autotoc_md69":[5,8,0,0],
@@ -247,7 +249,5 @@ var NAVTREEINDEX17 =
 "structpw__client__node__methods.html#a0d45045558276d9594008b5ac39ad404":[10,7,0,3,2],
 "structpw__client__node__methods.html#a1db43e226468e68a6a52292aa6a894c6":[10,7,0,3,7],
 "structpw__client__node__methods.html#acf64a3bd71fd790592e41458a4793c62":[10,7,0,3,0],
-"structpw__client__node__methods.html#ae7a71dd91cda53767aa31aa10c050244":[10,7,0,3,5],
-"structpw__client__session.html":[10,7,4,23],
-"structpw__client__session__events.html":[10,7,4,8]
+"structpw__client__node__methods.html#ae7a71dd91cda53767aa31aa10c050244":[10,7,0,3,5]
 };
