@@ -1,5 +1,13 @@
 var NAVTREEINDEX21 =
 {
+"structspa__i18n__methods.html#a7ceb5c3a7165fbfb3ee340574881d675":[10,8,9,2,2,1],
+"structspa__i18n__methods.html#a884391486c3277069fb8ee2f9d754234":[10,8,9,2,2,2],
+"structspa__interface.html":[10,8,8,5,2],
+"structspa__interface.html#a2572eec5caf615f77e143013373cdcdf":[10,8,8,5,2,1],
+"structspa__interface.html#a99da3754855d6dd1430d21ed97fa0bfb":[10,8,8,5,2,0],
+"structspa__interface.html#ae748ef778a029468d301c3727c80a85b":[10,8,8,5,2,2],
+"structspa__interface__info.html":[10,8,9,5,2],
+"structspa__interface__info.html#acdbeeba8f234386bc1a937604c234e40":[10,8,9,5,2,0],
 "structspa__io__buffers.html":[10,8,6,6],
 "structspa__io__buffers.html#a1364df7bc201533525e5a4fa54f444fe":[10,8,6,6,0],
 "structspa__io__buffers.html#aadfe10a114c998d88137450877d8326b":[10,8,6,6,1],
@@ -241,13 +249,5 @@ var NAVTREEINDEX21 =
 "structspa__pod__builder__callbacks.html#ad6d4638170f1441ba8c786ea174df911":[10,8,0,10,0],
 "structspa__pod__builder__state.html":[10,8,0,9],
 "structspa__pod__builder__state.html#a9406fb7fd6f0ea3cc9e99c9be6d76661":[10,8,0,9,1],
-"structspa__pod__builder__state.html#ac64c9a0aad0f5630c44c86e97561ffae":[10,8,0,9,0],
-"structspa__pod__builder__state.html#ad4d8cb79bdf194c752fc697eb7d63341":[10,8,0,9,2],
-"structspa__pod__bytes.html":[10,8,0,27],
-"structspa__pod__bytes.html#acf53b79878e4a426d95574190055b5e8":[10,8,0,27,0],
-"structspa__pod__choice.html":[10,8,0,34],
-"structspa__pod__choice.html#aa9927ee9a4a320384560480e1783705c":[10,8,0,34,1],
-"structspa__pod__choice.html#af1123be5c1dd70873b8d9ff4ea1ad8ed":[10,8,0,34,0],
-"structspa__pod__choice__body.html":[10,8,0,33],
-"structspa__pod__choice__body.html#a20700829b69701c8243986c02a5eeb67":[10,8,0,33,2]
+"structspa__pod__builder__state.html#ac64c9a0aad0f5630c44c86e97561ffae":[10,8,0,9,0]
 };
