@@ -1,5 +1,6 @@
 var NAVTREEINDEX7 =
 {
+"group__pw__session__manager.html#gaa17ffb9525d1063cdff54c7dcc5cda2d":[10,7,4,106],
 "group__pw__session__manager.html#gaa402cd6473e92b77d7f66d42dba6720f":[10,7,4,86],
 "group__pw__session__manager.html#gaa50cf4a5a59e55e6a003e21cc6376996":[10,7,4,44],
 "group__pw__session__manager.html#gaa5330ba264cb1a5af498d1a4b33d85ae":[10,7,4,155],
@@ -248,6 +249,5 @@ var NAVTREEINDEX7 =
 "group__spa__ansi.html#ga67b64705e0973206f62671580235ad91":[10,8,8,0,36],
 "group__spa__ansi.html#ga7e7da142af610c73f650312677383d99":[10,8,8,0,13],
 "group__spa__ansi.html#ga81bfa95fac68a133fd545e7fa4e9d1d1":[10,8,8,0,5],
-"group__spa__ansi.html#ga82142b091ace82f6742527d72cb3a9e4":[10,8,8,0,52],
-"group__spa__ansi.html#ga8b943fd646e64cbd0fa60484a0900d94":[10,8,8,0,19]
+"group__spa__ansi.html#ga82142b091ace82f6742527d72cb3a9e4":[10,8,8,0,52]
 };
