@@ -1,5 +1,6 @@
 var NAVTREEINDEX8 =
 {
+"group__spa__ansi.html#ga8b943fd646e64cbd0fa60484a0900d94":[10,8,8,0,19],
 "group__spa__ansi.html#ga8dcc1e4283933e216eca2305dda3ccf6":[10,8,8,0,12],
 "group__spa__ansi.html#ga9691e3321fd9a291860a04b0d219d52f":[10,8,8,0,41],
 "group__spa__ansi.html#ga9729d30d15a0ab085f74de854ec68baa":[10,8,8,0,11],
@@ -248,6 +249,5 @@ var NAVTREEINDEX8 =
 "group__spa__device.html#ga9fc516e68fefb9e3c7f08a5fa4ac8242":[10,8,4,22],
 "group__spa__device.html#gaa6141368f70a58863efc5494673903ba":[10,8,4,33],
 "group__spa__device.html#gaa8e69a2fae59e8d6d1d1da5f0660cbc3":[10,8,4,13],
-"group__spa__device.html#gab347a871f54232e2f8362c60fd893128":[10,8,4,21],
-"group__spa__device.html#gab68858d85274969e6f2502e95547f429":[10,8,4,51]
+"group__spa__device.html#gab347a871f54232e2f8362c60fd893128":[10,8,4,21]
 };
